# eric7.eric7_doc

eric Documentation Generator.

This is the main Python script of the documentation generator. It is this script that gets called via the source documentation interface. This script can be used via the commandline as well.

### Global Attributes

supportedExtensions

### Classes

None

### Functions

main | Main entry point into the application.
usage | Function to print some usage information.
version | Function to show the version information.

## main

main()

Main entry point into the application.

Up

## usage

usage()

Function to print some usage information.

It prints a reference of all commandline parameters that may be used and ends the application.

Up

## version

version()

Function to show the version information.

Up